# CBICQC

Essential quality control analysis of routine phantom stability MRI with single session and trend reporting

## Current Version ##
2020.12.02

## Dependencies
| Package | Minimum Version |
| ------- | --------------- |
| pydicom | 1.2.2 |
| numpy | 1.15.2 |
| statsmodels | 0.9.0 |
| pynetdicom | 1.2.0 |
| pybids | 0.12.4 |
| scipy | 1.5.4 |
| nibabel | 3.2.1 |
| nipype | 1.6.0 |
| reportlab | |
| scikit-image |

## Installation

```pip3 install cbicqc```  
```python setup.py install```
